@@ -92,6 +92,7 @@ class SetupReproParameters(NamedTuple):
     * install_last_lts: If True download last LTS version of mongo.
     * install_last_continuous: If True download last continuous version of mongo.
     * ignore_failed_push: Download version even if the push task failed.
+    * fallback_to_master: Should the latest master be downloaded if the version doesn't exist.
 
     * evg_version_file: Write which evergreen version were downloaded from to this file.
 
@@ -107,6 +108,7 @@ class SetupReproParameters(NamedTuple):
     install_last_lts: bool
     install_last_continuous: bool
     ignore_failed_push: bool
+    fallback_to_master: bool
 
     evg_version_file: Optional[str]
 
@@ -205,8 +207,8 @@ class SetupReproOrchestrator:
         """
         multiversionconstants = self.resmoke_proxy.get_multiversion_constants()
         releases = {
-            multiversionconstants.LAST_LTS_FCV: install_last_lts,
-            multiversionconstants.LAST_CONTINUOUS_FCV: install_last_continuous,
+            multiversionconstants.last_lts_fcv: install_last_lts,
+            multiversionconstants.last_continuous_fcv: install_last_continuous,
         }
         LOGGER.debug("LTS and continuous release inclusions", releases=releases)
         out = {
@@ -256,6 +258,7 @@ class SetupReproOrchestrator:
                     setup_repro_params.variant,
                     download_target,
                     setup_repro_params.ignore_failed_push,
+                    setup_repro_params.fallback_to_master,
                 )
 
                 if urls_info is None:
@@ -320,6 +323,8 @@ class SetupReproEnv(Subcommand):
         debug=None,
         ignore_failed_push=False,
         evg_versions_file=None,
+        resmoke_cmd=None,
+        fallback_to_master=False,
     ):
         """Initialize."""
         setup_logging(debug)
@@ -342,11 +347,13 @@ class SetupReproEnv(Subcommand):
             install_last_lts=install_last_lts,
             install_last_continuous=install_last_continuous,
             ignore_failed_push=ignore_failed_push,
+            fallback_to_master=fallback_to_master,
             download_options=download_options,
             evg_version_file=evg_versions_file,
         )
 
         self.evg_api = evergreen_conn.get_evergreen_api(evergreen_config)
+        self.resmoke_cmd = resmoke_cmd
 
     def execute(self):
         """Execute setup repro env mongodb."""
@@ -355,6 +362,7 @@ class SetupReproEnv(Subcommand):
             """Define dependencies for execution."""
             binder.bind(SetupReproEnvConfig, SETUP_REPRO_ENV_CONFIG)
             binder.bind(EvergreenApi, self.evg_api)
+            binder.bind(ResmokeProxy, ResmokeProxy.with_cmd(self.resmoke_cmd))
 
         inject.configure(dependencies)
 
@@ -429,6 +437,8 @@ class SetupReproEnvPlugin(PluginInterface):
             ignore_failed_push=(not args.require_push),
             evg_versions_file=args.evg_versions_file,
             debug=args.debug,
+            resmoke_cmd=args.resmoke_cmd,
+            fallback_to_master=args.fallback_to_master,
         )
 
     @classmethod
@@ -549,6 +559,21 @@ class SetupReproEnvPlugin(PluginInterface):
             action="store_true",
             help="Require the push task to be successful for assets to be downloaded",
         )
+        parser.add_argument(
+            "--resmokeCmd",
+            dest="resmoke_cmd",
+            default="python buildscripts/resmoke.py",
+            help="Command to invoke resmoke.py",
+        )
+        parser.add_argument(
+            "--fallbackToMaster",
+            dest="fallback_to_master",
+            action="store_true",
+            help=(
+                "Fallback to downloading the latest binaries from master if the requested "
+                "version is not found (Only application for mongo versions)"
+            ),
+        )
         # Hidden flag to write out the Evergreen versions of the downloaded binaries.
         parser.add_argument(
             "--evgVersionsFile", dest="evg_versions_file", default=None, help=argparse.SUPPRESS
